// 存放本项目一些通用的方法
import axios from 'axios'
import Lodash from 'lodash'
import {
  Toast
} from 'mint-ui'
import Store from '@/vuex';
let axiosInstance = axios.create({
  timeout: 15000,
  headers: {
    'Content-Type': 'application/json',
  }
});

// let Toast = {

// }
const util = {
  // 对首页loading控件的显示和关闭
  showLoading() {
    Store.commit("setShowPageLoading", true);
  },
  hideLoading() {
    Store.commit("setShowPageLoading", false);
  },
  /**
   * 封装一个log方便调试看数据
   * @param {} value 要打印的值
   * @param {string} des 描述文字
   */
  log(value, des) {
    if (typeof value == "object") {
      console.log(`\n${des?des+':':''}${JSON.stringify(value)}\n`);
    } else {
      console.log(`\n${des?des+':':''}${value}\n`);
    }
  },
  /**
   * 
   * @param {String} url 请求地址
   * @param {Object} param 请求参数
   * @param {Function} success 请求发送成功的回调
   * @param {Function} fail 请求发送失败的回调
   * @param {Boolean} toast 失败是否需要默认toast
   * @param {Boolean} loading 是否需要加载loading
   */
  req(url, param, success, fail, toast = true, loading = true) {
    loading && this.showLoading();
    if (!url.startsWith('http')) {
      url = Store.state.dataFromNative.baseServerUrl + url;
    }
    this.log(url, "发起请求");
    this.log(param, "param");
    if (url.indexOf('?') > 0) {
      axiosInstance.get(url, param).then(res => {
          // this.log(res, "请求成功，返回信息：：：")
          this.log(res.data, "请求返回数据")
          typeof success == 'function' && success(res.data);
          loading && this.hideLoading();
        })
        .catch(err => {
          this.log(err, "请求失败")
          loading && this.hideLoading();
          // toast && Toast('当前网络不佳,请重试')
          typeof fail == 'function' && fail(err);
        });
    } else {
      axiosInstance.post(url, param).then(res => {
        // this.log(res, "请求成功，返回信息：：：")
        this.log(res.data, "请求返回数据")
        typeof success == 'function' && success(res.data);
        loading && this.hideLoading();
      })
      .catch(err => {
        this.log(err, "请求失败")
        loading && this.hideLoading();
        // toast && Toast('当前网络不佳,请重试')
        typeof fail == 'function' && fail(err);
      });
    }
  },
  /**
   * 转换16进制数据为10进制
   * @param {Object} obj 要转换的对象
   * @param {Array} 要跳过的属性数组
   */
  HEXToDEC(obj, skipKeys = []) {
    for (const key in obj) {
      if (obj.hasOwnProperty(key)) {
        let skip = false;
        for (const skipItem of skipKeys) {
          if (key == skipItem) skip = true;
        }
        if (skip) {
          continue;
        };
        let item = obj[key];
        (typeof item == "number" || typeof item == "string") && (obj[key] = parseInt(item, 16));
      }
    }
  },
  /**
   * 转换10进制数据为16进制
   * @param {Object} obj 要转换的对象
   * @param {Array} 要跳过的属性数组
   */
  DECToHEX(obj, skipKeys = []) {
    for (const key in obj) {
      if (obj.hasOwnProperty(key)) {
        let skip = false;
        for (const skipItem of skipKeys) {
          if (key == skipItem) skip = true;
        }
        if (skip) {
          continue;
        };
        let item = obj[key];
        (typeof item == "number" || typeof item == "string") && (obj[key] = Number(item).toString(16).toLocaleUpperCase());
      }
    }
  },

  /**
   * 判断设备回复的时间是否有效（在当前时间之后）
   * @param {Object} data 设备回复的转为10进制之后的数据，需要包含年月日时分秒，函数执行过程不会修改该对象
   */
  ifTimeEffect(data) {
    if (!data.Year || data.Year == "0") return null;
    let month = 12 - Lodash.padStart(data.Month.toString(2), 12, "0").indexOf('1');
    let date = new Date("20" + data.Year, month - 1, data.Day, data.Hour, data.Minute, data.Second),
      now = new Date();
    this.log(date.toLocaleString(), "执行操作的时间：：：");
    if (date.getTime() > now) {
      return true;
    } else {
      return false;
    }
  },
  // 从影子设备获取设备全状态
  qryDeviceStatusFromShadow(callback) {
    this.req(Store.state.dataFromNative.shadowServerUrl, {
        method: "get",
        sn: Store.state.dataFromNative.blueToothDeviceId,
      },
      res => {
        if (res.code == 200) {
          if (!res.result.payload || !res.result.payload.state) return;
          let data = res.result.payload.state.reported;
          this.HEXToDEC(data);
          callback(data);
        } else {
          Toast("获取设备状态失败");
        }
      }
    )
  },
  /**
   * 用于页面接收指令返回数据时候存入或更新指令返回信息。如果有重复的（返回的key相同），则更新，如果没有重复的，则push。一次仅操作一个数据对象
   * @param {Array} pageDatas 页面用于存储指令回复数据的数组 
   * @param {Object} receivedData 本次接收到要用于更新的指令对象
   */
  updateCommandReceivedDatas(pageDatas, receivedData) {
    let index = pageDatas.findIndex(itme => Object.keys(itme).join("") == Object.keys(receivedData).join(""));
    if (index >= 0) {
      pageDatas[index] = receivedData;
      return;
    }
    pageDatas.push(receivedData);
  },

  // 判别是否包含Emoji表情
 containsEmoji(str) {
  var regRule = /\uD83C[\uDF00-\uDFFF]|\uD83D[\uDC00-\uDE4F]/g;
  if(str.match(regRule)) {
    return true
  }else{
    return false
  }
}
}

let ToastBottom = (msg)=>{
  Toast({
    message: msg,
    position: "bottom"
  });
}

export { ToastBottom as Toast}
export default util
